import Vue from 'vue';
import Router from 'vue-router';
import Home from './views/Home.vue';

Vue.use(Router);

const router = new Router({
  mode: process.env.VUE_APP_ROUTER_MODE || 'history',
  base: process.env.BASE_URL,
  routes: [
    {
      path: '/',
      redirect: '/frame',
    },
    {
      path: '/login',
      component: () => import(/* webpackChunkName: "login" */ './views/Login.vue'),
      children: [
        {
          path: '/:unit/login',
        },
      ],
    },
    {
      path: '/loginTow',
      component: () => import(/* webpackChunkName: "login" */ './views/LoginTow.vue'),
    },
    {
      path: '/frame',
      component: () => import(/* webpackChunkName: "frame" */ './views/Frame.vue'),
      children: [
        {
          path: '/frame',
          component: Home,
        },
        {
          path: '/frame/:module/:app/:path(.*)',
        },
        {
          path: '/frame/:module/:app',
        },
        {
          path: '/frame/:module',
        },
      ],
    },
    {
      path: '/frame2',
      component: () => import(/* webpackChunkName: "frame" */ './views/FrameTow.vue'),
      children: [
        {
          path: '/frame2',
          component: Home,
        },
        {
          path: '/frame2/:module/:app/:path(.*)',
        },
        {
          path: '/frame2/:module/:app',
        },
        {
          path: '/frame2/:module',
        },
      ],
    },
  ],
});

router.beforeEach((to, from, next) => {
  if (to.path == from.path) return;
  const { isAuthenticated } = router.$store.getters;
  if (!isAuthenticated && !/\/login$/.test(to.path)) {
    console.warn('not login, redirect login page...');
    next('/login');
    return;
  }
  if (isAuthenticated && /\/login$/.test(to.path)) {
    // 清空登录状态
    console.warn('User back to login page, login status is cleared!');
    router.$store.dispatch('login/logout');
    return;
  }
  if (isAuthenticated && '/index.html' == to.path) {
    next('/frame');
    return;
  }
  console.debug('page from: ', from);
  console.debug('page to: ', to);
  router.$store.commit('naf/menu/NAV_MODULE_SELECTED', to.params.module);
  next();
});

export default router;
