import * as types from './mutation-types';
import util from '@lib/utils/user-util';

const api = {
  login: '/gaf/login',
  passwd: '/gaf/users/passwd',
};

export const state = () => ({
  loading: false,
  isAuthenticated: util.user && util.user.role !== 'guest',
  userinfo: util.user,
  roles: util.roles,
  // isAuthenticated: true,
  // userinfo: { name: '默认管理员' },
});

// getters
export const getters = {
  userStatus: state => (state.userinfo || {}).status,
};

// actions
export const actions = {
  async login({ commit, dispatch, state }, { username, password, code, uuid }) {
    commit(types.SHOW_LOADING);
    try {
      // console.log(this.$axios);
      let res = await this.$axios.$post(api.login, { username, password }, { state: uuid, code });
      // let res = { userinfo: { name } };
      // console.log(res);
      if (res.errcode && res.errcode !== 0) {
        commit(types.LOGIN_FAILURE);
      } else {
        // await dispatch('fetch', { username });
        commit(types.LOGIN_SUCCESS, res);
        // 重新加载菜单
        await dispatch('naf/menu/load', null, { root: true });
      }
      return res;
    } catch (err) {
      console.error(err);
      commit(types.LOGIN_FAILURE);
      return { errcode: -1, errmsg: 'error' };
    } finally {
      commit(types.HIDE_LOADING);
    }
  },
  async fetch({ commit /* , state */ }, { username }) {
    const res = await this.$axios.$get('/userinfo', { username });
    const { userinfo } = res;
    commit(types.USER_INFO, userinfo);
    return res;
  },
  async logout({ commit }) {
    // const res = await this.$axios.$post('/logout')
    // if (res.errcode != undefined && res.errcode === 0) {
    //   commit(types.LOGOUT_SUCCESS);
    // }
    // return res;
    commit(types.LOGOUT_SUCCESS);
    return { errcode: 0, errmsg: 'ok' };
  },
  async passwd({ state }, { oldpass, newpass }) {
    const { userId } = state.userinfo;
    const res = await this.$axios.$post(api.passwd, { oldpass, newpass }, { userId });
    return res;
  },
};

// mutations
export const mutations = {
  [types.SHOW_LOADING](state) {
    state.loading = true;
  },
  [types.HIDE_LOADING](state) {
    state.loading = false;
  },

  [types.LOGIN_SUCCESS](state, { userinfo, token, roles }) {
    state.isAuthenticated = true;
    state.userinfo = userinfo;
    state.roles = roles;
    util.save({ userinfo, token, roles });

    // TODO: 重定向到框架界面
    // this.$router.push('/frame');
  },
  [types.LOGIN_FAILURE](state) {
    state.isAuthenticated = false;
  },
  [types.LOGOUT_SUCCESS](state) {
    state.isAuthenticated = false;
    state.userinfo = null;
    this.$router.push('/login');
    util.save({});
  },
  [types.USER_INFO](state, payload) {
    state.userinfo = payload;
  },
};

export const namespaced = true;
