import * as Cookies from 'js-cookie';
import * as types from './.menu';
import config from '@frame/config';

// 转换菜单数据，构建菜单组件需要的数据
const MapMenu = ({ catalog = [], module = undefined, menuRoles = {} } = {}) => item => ({
  title: item.title,
  options: {
    icon: item.icon,
    path: `/${item.module || module}${item.path}`,
    url: item.url,
    target: item.target,
    tooltip: item.tooltip,
    module: item.module,
    platform: item.platform,
    roles: item.id && menuRoles[item.id], // item.roles,
    tags: item.tags,
    visible: item.visible,
    meta: { catalog: catalog.concat(item.title) },
  },
  children: (item.children || [])
    .filter(p => p.visible != false)
    .map(MapMenu({ catalog: catalog.concat(item.title), module: item.module || module, menuRoles })),
});
// 检查菜单权限
const checkPermits = (menu, userRoles = []) => {
  // console.debug('userRoles', userRoles);
  return !menu.options.roles || menu.options.roles.some(p => userRoles.indexOf(p) != -1) || userRoles.indexOf('superadmin') != -1;
};
const filterPermits = (items, userRoles = []) => {
  return items
    .filter(p => checkPermits(p, userRoles))
    .map(p => {
      if (p.children) p.children = filterPermits(p.children, userRoles);
      return p;
    });
};

const { menuMode = 'nested' } = config;
const defaultMode = menuMode.startsWith('lite') ? 'lite' : 'nested';
const switchable = !menuMode.endsWith('Only');
// initial state
// shape: [{ id, quantity }]
export const state = () => ({
  items: [],
  modules: [],
  current: null,
  mode: Cookies.get('navMode') || defaultMode, // nested-两层嵌套导航（导航条+导航树）; lite-单一树状导航
  collapse: false,
  switchable,
});

// actions
export const actions = {
  // obsolete
  async _load({ commit }) {
    try {
      let res = await this.$axios.$get('/menu/load');
      if (res.errcode) {
        return res;
      }
      commit(types.NAV_MENU_LOADED, res.data || res);
    } catch (err) {
      console.error(err);
      return { errcode: -1, errmsg: err.message || '处理失败' };
    }
  },
  async switchMode({ commit }, payload) {
    commit(types.NAV_SWITCH_MODE, payload);
    if (process.browser) {
      Cookies.set('navMode', payload);
    }
  },
  async load({ commit, rootGetters }) {
    try {
      // 加载角色信息
      res = await this.$axios.$get('/gaf/role/items');
      if (res.errcode) {
        return res;
      }
      const roleDict = res.data.reduce((p, c) => {
        p[c.id] = c.code;
        return p;
      }, {});
      // 加载菜单角色信息
      res = await this.$axios.$get('/gaf/bind/menu-role/items');
      if (res.errcode) {
        return res;
      }
      const menuRoles = res.data
        .map(p => ({ menuId: p.source, roleId: p.target }))
        .reduce((p, c) => {
          p[c.menuId] = [...(p[c.menuId] || []), roleDict[c.roleId] || c.roleId];
          return p;
        }, {});

      // 加载导航菜单树数据
      let res = await this.$axios.$get('/gaf/menu/items');
      if (res.errcode) {
        return res;
      }
      let items = (res.data || res || []).filter(p => p.visible != false).map(MapMenu({ menuRoles }));
      items = filterPermits(items, rootGetters.roles);

      // 加载横向菜单条数据
      res = await this.$axios.$get('/gaf/menu/menus');
      if (res.errcode) {
        return res;
      }
      const modules = (res.data || res || []).filter(p => p.visible != false).map(MapMenu());

      commit(types.NAV_MENU_LOADED, { items, modules });
    } catch (err) {
      console.error(err);
      return { errcode: -1, errmsg: err.message || '处理失败' };
    }
  },
};

// mutations
export const mutations = {
  [types.NAV_MENU_LOADED](state, { items, modules }) {
    state.items = items;
    state.modules = modules;
  },
  [types.NAV_MODULE_SELECTED](state, payload) {
    state.current = payload;
  },
  [types.NAV_SWITCH_MODE](state, payload) {
    state.mode = payload;
  },
  [types.NAV_TOGGLE_COLLAPSE](state, payload) {
    state.collapse = !state.collapse;
  },
};

export const namespaced = true;
