import * as types from '../.mutation.js';
import _ from 'lodash';

const baseUrl = '/gaf/dept/items';

// initial state
// shape: [{ id, quantity }]
export const state = () => ({
  items: [], //所有数据
  current: null,
  currentForm: null,
});

// actions
export const actions = {
  async load({ commit }, payload = {}) {
    const { pid = '' } = payload;
    // const res = await this.$axios.$get(`${baseUrl}`, { params: { pid, recursive: true } });
    const res = await this.$axios.$get(`${baseUrl}`, { pid, recursive: true });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res.data);
    }
    return res;
  },
  async create({ commit, state }, payload) {
    const { pid = '', code, name, remark } = payload;
    const res = await this.$axios.$post(`${baseUrl}`, { code, name, remark }, { params: { pid } });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.CREATED, res);
    }
    return res;
  },
  async delete({ commit, state }, { id }) {
    const res = await this.$axios.$delete(`${baseUrl}/${id}`);
    if (res.errcode === undefined || res.errcode === 0) commit(types.DELETED, { id });
    return res;
  },
  async update({ commit, state }, payload = {}) {
    const { id, name, code, remark } = payload;
    const res = await this.$axios.$post(`${baseUrl}/${id}`, { code, name, remark });
    if (res.errcode === undefined || res.errcode === 0) commit(types.UPDATED, res);
    return res;
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, payload) {
    state.items = payload;
  },
  [types.SELECTED](state, payload) {
    state.current = payload;
  },
  [types.CREATED](state, payload) {
    state.items.push(payload);
    state.total += 1;
    state.currentForm = payload;
  },
  [types.DELETED](state, payload) {
    let idx = state.items.findIndex(p => p.id === payload.id);
    state.items.splice(idx, 1);
  },
  [types.UPDATED](state, payload) {
    let idx = state.items.findIndex(p => p.id === payload.id);
    state.items.splice(idx, 1, payload);
    state.currentForm = payload;
  },
  setForm(state, payload) {
    state.currentForm = payload;
  },
};
