import Vue from 'vue';
import * as types from '../.mutation.js';
import config from '@frame/config';
const { pageSize = 10 } = config;

const api = {
  items: '/gaf/logs',
  values: field => `gaf/logs/${field}/values`,
};
// initial state
export const state = () => ({
  items: [], //所有数据
  current: null,
  total: 0, // 字典项总数
  values: {},
});

// actions
export const actions = {
  async load({ commit }, { filter = {}, paging = {} } = {}) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const res = await this.$axios.$get(`${api.items}`, { ...filter, skip, limit: size });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
  async loadValues({ commit }) {
    const fields = ['module', 'event', 'action', 'result'];
    fields.forEach(async field => {
      const res = await this.$axios.$get(api.values(field));
      if (res.errcode === undefined || res.errcode === 0) {
        commit('values', { ...res, field });
      }
    });
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, { data, total }) {
    state.items = data;
    state.total = total;
  },
  [types.SELECTED](state, payload) {
    state.current = payload;
  },
  values(state, { field, data }) {
    Vue.set(state.values, field, data);
  },
};
