import Vue from 'vue';
import * as types from '../.mutation.js';

const api = {
  items: '/gaf/menu/items',
  bindRole: '/gaf/bind/menu-role/items',
};
// initial state
export const state = () => ({
  items: [], //所有数据
  current: null,
  roleIds: {}, // 当前菜单的角色ID列表
});

// actions
export const actions = {
  async load({ commit, dispatch }) {
    const res = await this.$axios.$get(`${api.items}`);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res.data || res);
      await dispatch('fetchRoles');
    }
    return res;
  },
  async fetchRoles({ commit, state }) {
    const res = await this.$axios.$get(`${api.bindRole}`);
    let ids = [];
    if (res.errcode && res.errcode !== 0) {
      console.warn('menu.fetchRoles error:', res);
    } else {
      const maps = res.data
        .map(p => ({ menuId: p.source, roleId: p.target }))
        .reduce((p, c) => {
          p[c.menuId] = [...(p[c.menuId] || []), c.roleId];
          return p;
        }, {});
      commit('roleIds', maps);
    }
    return res;
  },
  async bindRoles({ commit, state }, { roleIds, menuId, replace = true } = {}) {
    // 同时绑定多个角色
    let res;
    if (roleIds && roleIds.length > 0) {
      res = await this.$axios.$post(`${api.bindRole}/batch`, { targets: roleIds, source: menuId }, { params: { replace, menuId } });
    } else if (replace) {
      // TODO: 删除所有角色
      res = await this.$axios.$delete(api.bindRole, { source: menuId });
    }
    if (res.errcode === undefined || res.errcode === 0) {
      // 刷新菜单角色列表
      commit('roleIds', { [menuId]: roleIds || [] });
    }
    return res;
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, payload) {
    state.items = payload;
  },
  [types.SELECTED](state, payload) {
    state.current = payload;
  },
  roleIds(state, payload) {
    state.roleIds = { ...state.roleIds, ...payload };
  },
};
