import Vue from 'vue';
import * as types from '../.mutation.js';

const api = {
  items: '/gaf/role/items',
};
// initial state
export const state = () => ({
  items: [], //所有标签数据
  roleDict: {}, // 角色字典
  userlist: [], //当前标签用户数据
  partylist: [], //当前标签部门数据
  current: null,
});

// actions
export const actions = {
  async load({ commit }) {
    const res = await this.$axios.$get(`${api.items}`);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res.data || res);
    }
    return res;
  },
  async create({ commit, state }, payload) {
    const { type, code, name, remark } = payload;
    const res = await this.$axios.$post(`${api.items}`, { type, code, name, remark });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.CREATED, res);
    }
    return res;
  },
  async delete({ commit, state }, { id }) {
    const res = await this.$axios.$delete(`${api.items}/${id}`);
    if (res.errcode === undefined || res.errcode === 0) commit(types.DELETED, { id });
    return res;
  },
  async update({ commit, state }, payload = {}) {
    const { id, name, remark } = payload;
    const res = await this.$axios.$post(`${api.items}/${id}`, { name, remark });
    if (res.errcode === undefined || res.errcode === 0) commit(types.UPDATED, res);
    return res;
  },
  async selectRole({ commit, dispatch }, payload = {}) {
    commit(types.SELECTED, payload);
    await dispatch('list');
  },
  async list({ commit, state }) {
    const { id } = state.current;
    const res = await this.$axios.$get(`${api.fetch}?id=${id}`);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LISTED, res);
    }
    return res;
  },
  async addusers({ dispatch, state }, payload = {}) {
    const { id } = state.current;
    const res = await this.$axios.$post(`${api.addroleusers}?id=${id}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      await dispatch('list');
    }
    return res;
  },
  async delusers({ dispatch, state }, payload = {}) {
    const { id } = state.current;
    const res = await this.$axios.$post(`${api.delroleusers}?id=${id}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      await dispatch('list');
    }
    return res;
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, payload) {
    state.items = payload;
    state.roleDict = state.items.reduce((p, c) => {
      p[c.id] = c;
      return p;
    }, {});
  },
  [types.SELECTED](state, payload) {
    state.current = payload;
  },
  [types.CREATED](state, payload) {
    state.items.push(payload);
    state.current = payload;
  },
  [types.DELETED](state, payload) {
    const idx = state.items.findIndex(p => p.id === payload.id);
    state.items.splice(idx, 1);
  },
  [types.UPDATED](state, payload) {
    const idx = state.items.findIndex(p => p.id === payload.id);
    // state.items.splice(idx, 1, payload);
    Vue.set(state.items, idx, payload);
    state.current = payload;
  },
  [types.LISTED](state, { userlist, partylist }) {
    state.userlist = userlist;
    state.partylist = partylist;
  },
};
