import * as types from '../.types.js';
import config from '@frame/config';
const { pageSize = 10 } = config;

const api = {
  items: '/xms/app/infos',
  roles: '/xms/app/roles',
  apps: '/xms/bff/acct/apps',
};
export const state = () => ({
  list: [], //所有数据
  items: [], //分页数据
  total: 0, // 总数
  current: null,
  roleItems: [], // 指定应用的角色列表
});
// actions
export const actions = {
  async create({ commit, state }, payload) {
    const res = await this.$axios.$post(`${api.items}`, payload);
    if (res && !res.errcode) {
      commit(types.CREATED, res);
    }
    return res;
  },
  async delete({ commit, state }, { appId }) {
    const res = await this.$axios.$delete(`${api.items}/${appId}`);
    if (res == null || (res && !res.errcode)) commit(types.DELETED, appId);
    return res;
  },
  async update({ commit, state }, payload = {}) {
    const { appId } = payload;
    const res = await this.$axios.$post(`${api.items}/${appId}`, payload);
    if (res.errcode === undefined || res.errcode === 0) commit(types.UPDATED, res);
    return res;
  },
  async query({ commit }, { filter = {}, paging = {} }) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const params = { ...filter, skip, limit: size, 'sort.property': 'name' };
    const res = await this.$axios.$get(`${api.items}`, { params });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
  async fetch({ commit }, payload = {}) {
    const { appId } = payload;
    if (!appId) {
      commit(types.DETAILS, {});
      return {};
    }
    const res = await this.$axios.$get(`${api.items}/${appId}`);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.DETAILS, res);
    }
    return res;
  },
  async list({ commit }, payload = {}) {
    const res = await this.$axios.$get(`${api.items}`, { limit: 500, 'sort.property': 'name' });
    if (payload.acctId) {
      const res2 = await this.$axios.$get(`${api.apps}`, { acctId: payload.acctId });
      var list = [];
      for (var i = 0; i < res.data.length; i++) {
        var boo = true;
        for (var j = 0; j < res2.data.length; j++) {
          if (res.data[i].appId == res2.data[j].appId) {
            boo = false;
          }
        }
        if (boo) {
          list.push(res.data[i]);
        }
        boo = true;
      }
      commit(types.LISTED, { data: list, total: res.total - res2.total });
      return { data: list, total: res.total - res2.total };
    }
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LISTED, res);
    }
    return res;
  },
  async fetchRoles({ commit }, { appId, type }) {
    if (!appId) {
      commit('roles', { data: [] }); // clear
      return;
    }
    const res = await this.$axios.$get(`${api.roles}`, { appId, type, limit: 500 });
    if (res.errcode === undefined || res.errcode === 0) {
      commit('roles', res);
    }
    return res;
  },
};
// mutations
export const mutations = {
  [types.LOADED](state, { data, total }) {
    state.items = data;
    state.total = total;
  },
  [types.CREATED](state, payload) {
    state.items.push(payload);
    state.total = state.total + 1;
  },
  [types.DELETED](state, payload) {
    const idx = state.items.findIndex(p => p.appId === payload);
    state.items.splice(idx, 1);
    state.total = state.total - 1;
  },
  [types.UPDATED](state, payload) {
    const idx = state.items.findIndex(p => p.appId === payload.appId);
    state.items.splice(idx, 1, payload);
  },
  [types.LISTED](state, { data }) {
    state.list = data;
  },
  roles(state, { data }) {
    state.roleItems = data;
  },
  datapush(state, payload) {
    state.list.unshift(payload);
  },
  [types.DETAILS](state, payload) {
    state.current = payload;
  },
};
