import * as types from '../.types.js';
import config from '@frame/config';
const { pageSize = 10 } = config;

const api = {
  resources: '/xms/app/resources',
  rolesres: '/xms/bff/role/resources',
};
// initial state
export const state = () => ({
  reslist: [], //所有数据
  total: 0, // 总数
  listrolres: [],
  current: null,
  currents: null,
});

// actions
export const actions = {
  // 查询某应用下某角色绑定的所有资源
  async loadRolRes({ commit }, payload) {
    const res = await this.$axios.$get(`${api.rolesres}?skip=${0}&limit=${1000}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      commit('LISTROLRES', res.data);
    }
    return res;
  },
  // 查询资源列表
  async load({ commit }, { appId, filter = {}, paging = {} }) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const params = { appId, ...filter, skip, limit: size };
    const res = await this.$axios.$get(`${api.resources}`, { params });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
  async create({ commit, state }, payload) {
    const res = await this.$axios.$post(`${api.resources}?appId=` + payload.appId, payload.data);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.CREATED, res);
    }
    return res;
  },
  async delete({ commit, state, dispatch }, { resId }) {
    const res = await this.$axios.$delete(`${api.resources}/${resId}`);
    commit(types.DELETED, resId);
    return res;
  },
  async batchDelete({ commit, state, dispatch }, { appId, list }) {
    list.every(async e => {
      const res = await this.$axios.$delete(`${api.resources}/${e}`);
      await dispatch('load', { appId });
      return res;
    });
  },
  async update({ commit, state }, payload = {}) {
    const { resId } = payload;
    // const res = await this.$axios.$post(`${api.items}/${groupId}`, payload);
    const res = await this.$axios.$post(`${api.resources}/${resId}`, payload);
    if (res.errcode === undefined || res.errcode === 0) commit(types.UPDATED, res);
    return res;
  },
  async resList({ commit }, payload) {
    const res = await this.$axios.$get(`${api.resources}?skip=${0}&limit=${1000}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LISTED, res.data);
    }
    return res;
  },
  async fetch({ commit }, payload = {}) {
    const { resId } = payload;
    if (!resId) {
      commit(types.DETAILS, null);
      return {};
    }
    const res = await this.$axios.$get(`${api.resources}/${resId}`);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.DETAILS, res);
    }
    return res;
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, { data, total }) {
    state.reslist = data;
    state.total = total;
  },
  [types.CREATED](state, payload) {
    state.current = payload;
    state.reslist.push(payload);
    state.total = state.total + 1;
  },
  [types.DELETED](state, payload) {
    const idx = state.reslist.findIndex(p => p.resId === payload);
    state.reslist.splice(idx, 1);
    state.total = state.total - 1;
  },
  [types.UPDATED](state, payload) {
    const idx = state.reslist.findIndex(p => p.resId === payload.resId);
    state.reslist.splice(idx, 1, payload);
  },
  [types.LISTED](state, payload) {
    state.reslist = payload;
  },
  ['LISTROLRES'](state, payload) {
    state.listrolres = payload;
  },
  [types.DETAILS](state, payload) {
    state.current = payload;
  },
  ['current'](state, payload) {
    state.currents = payload;
  },
};
