import * as types from '../.types.js';
import config from '@frame/config';
const { pageSize = 10 } = config;

const api = {
  roles: '/xms/app/roles',
  roleresbind: '/xms/bind/role-res/items',
  resroles: '/xms/bff/resource/roles',
  rolerolebind: '/xms/bind/role-role/items',
  rolerole: '/xms/bff/role/roles',
};
// initial state
export const state = () => ({
  roleslist: [], //所有角色和角色组数据
  rolelist: [], //所有角色数据
  total: 0, // 总数
  listresrol: [], //某资源绑定的所有角色
  rolerole: [], //某角色组绑定的所有角色
  current: null,
});

// actions
export const actions = {
  async fetch({ commit }, payload = {}) {
    const { roleId } = payload;
    if (!roleId) {
      commit(types.DETAILS, null);
      return {};
    }
    const res = await this.$axios.$get(`${api.roles}/${roleId}`);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.DETAILS, res);
    }
    return res;
  },
  // 查询某应用下某资源绑定的所有角色
  async loadResRol({ commit }, payload) {
    const res = await this.$axios.$get(`${api.resroles}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      commit('LISTRESROL', res.data);
    }
    return res;
  },
  // 资源角色绑定
  async roleresBind({ commit, state }, { roleId, resId, appId, ror, replace = false } = {}) {
    if (ror === 'role' && resId.length > 1) {
      return await this.$axios.$post(`${api.roleresbind}/batch`, { source: roleId, targets: resId, appId }, { params: { replace } });
    }
    if (ror === 'role' && resId.length == 1) {
      return await this.$axios.$post(`${api.roleresbind}`, { source: roleId, target: resId[0], appId });
    }
    if (ror === 'res' && roleId.length > 1) {
      return await this.$axios.$post(`${api.roleresbind}/batch`, { sources: roleId, target: resId, appId }, { params: { replace } });
    }
    if (ror === 'res' && roleId.length == 1) {
      return await this.$axios.$post(`${api.roleresbind}`, { source: roleId[0], target: resId, appId });
    }
  },
  async roleresDel({ commit, state }, { roleId, resId, appId, ror, replace = false } = {}) {
    if (ror === 'role' && resId.length > 1) {
      // return await this.$axios.$delete(`${api.roleresbind}/delete?source=${roleId}&targets=${resId}&appId=${appId}`);
      return await this.$axios.$post(`${api.roleresbind}/delete`, { source: roleId, targets: resId, appId });
    }
    if (ror === 'role' && resId.length == 1) {
      return await this.$axios.$delete(`${api.roleresbind}`, { source: roleId, target: resId[0], appId });
    }
    if (ror === 'res' && roleId.length > 1) {
      return await this.$axios.$post(`${api.roleresbind}/delete`, { sources: roleId, target: resId, appId });
    }
    if (ror === 'res' && roleId.length == 1) {
      return await this.$axios.$delete(`${api.roleresbind}`, { source: roleId[0], target: resId, appId });
    }
  },
  // 查询某应用下某角色组绑定的所有角色
  async loadRoleRole({ commit }, payload) {
    const res = await this.$axios.$get(`${api.rolerole}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      commit('ROLEROLE', res.data);
    }
    return res;
  },
  // 角色绑定角色组
  // eslint-disable-next-line no-dupe-keys
  async roleroleBind({ commit, state }, { rolesId, roleId, appId, replace = false } = {}) {
    if (roleId.length > 1) {
      return await this.$axios.$post(`${api.rolerolebind}/batch`, { source: rolesId, targets: roleId, appId }, { params: { replace } });
    } else {
      return await this.$axios.$post(`${api.rolerolebind}`, { source: rolesId, target: roleId[0], appId });
    }
  },
  // 解除角色组和角色绑定
  async roleroleDel({ commit, state }, { rolesId, roleId, appId } = {}) {
    if (roleId.length > 1) {
      return await this.$axios.$post(`${api.rolerolebind}/delete`, { source: rolesId, targets: roleId, appId });
    } else {
      return await this.$axios.$delete(`${api.rolerolebind}`, { source: rolesId, target: roleId[0] });
    }
  },
  async load({ commit }, { type, appId, filter = {}, paging = {} } = {}) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const params = { ...filter, skip, limit: size };
    if (appId) params.appId = appId;
    if (type) params.type = type;
    const res = await this.$axios.$get(`${api.roles}`, { params });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
  async roleList({ commit }, payload) {
    const res = await this.$axios.$get(`${api.roles}?skip=${0}&limit=${1000}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LISTED, res.data);
    }
    return res;
  },
  async create({ commit, state }, payload) {
    const res = await this.$axios.$post(`${api.roles}` + '?appId=' + payload.appId + '&type=' + payload.data.type, payload.data);
    if (res && !res.errcode) {
      commit(types.CREATED, res);
    }
    return res;
  },
  async delete({ commit, state }, { roleId }) {
    const res = await this.$axios.$delete(`${api.roles}/${roleId}`);
    if (res && !res.errcode) {
      commit(types.DELETED, roleId);
    }
    return res;
  },
  async update({ commit, state }, payload = {}) {
    const { roleId } = payload;
    const res = await this.$axios.$post(`${api.roles}/${roleId}`, payload);
    if (res.errcode === undefined || res.errcode === 0) commit(types.UPDATED, res);
    return res;
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, { data, total }) {
    state.roleslist = data;
    state.total = total;
  },
  [types.CREATED](state, payload) {
    state.current = payload;
    state.total = state.total + 1;
    state.roleslist.push(payload);
  },
  [types.DELETED](state, payload) {
    const idx = state.roleslist.findIndex(p => p.roleId === payload);
    state.roleslist.splice(idx, 1);
    state.total = state.total - 1;
  },
  [types.UPDATED](state, payload) {
    const idx = state.roleslist.findIndex(p => p.roleId === payload.roleId);
    state.roleslist.splice(idx, 1, payload);
  },
  [types.LISTED](state, payload) {
    state.rolelist = payload;
  },
  ['LISTRESROL'](state, payload) {
    state.listresrol = payload;
  },
  ['ROLEROLE'](state, payload) {
    state.rolerole = payload;
  },
  [types.DETAILS](state, payload) {
    state.current = payload;
  },
};
