import * as types from '../.types.js';
import config from '@frame/config';
const { pageSize = 10 } = config;

const api = {
  resources: '/xms/terminal/infos',
  rolesres: '/xms/bff/terminal/users',
  userbind: '/xms/bind/terminal-user/items',
};
// initial state
export const state = () => ({
  items: [], //所有数据
  total: 0, // 总数
  useritems: [],
  usertotal: 0,
  listrolres: [],
  current: null,
  currents: null,
});

// actions
export const actions = {
  // 查询终端列表
  async load({ commit }, { appId, filter = {}, paging = {} }) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const params = { appId, ...filter, skip, limit: size };
    const res = await this.$axios.$get(`${api.resources}`, { params });
    if (!res.errcode || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
  // 查询终端人员列表
  async userload({ commit }, { terminalId, filter = {}, paging = {} }) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const params = { terminalId, ...filter, skip, limit: size };
    const res = await this.$axios.$get(`${api.rolesres}`, { params });
    if (!res.errcode || res.errcode === 0) {
      commit(types.USERLOADED, res);
    }
    return res;
  },
  // 绑定用户
  async userbind({ commit, state }, payload) {
    const data = {
      source: payload.terminalId,
      target: payload.userId,
      userId: payload.userId,
    };
    const res = await this.$axios.$post(api.userbind, data);
    return res;
  },
  // 解绑
  async userunbind({ commit, state }, payload) {
    const data = {
      source: payload.terminalId,
      target: payload.userId,
      userId: payload.userId,
    };
    const res = await this.$axios.$delete(api.userbind, data);
    return res;
  },
  async create({ commit, state }, payload) {
    const res = await this.$axios.$post(api.resources, payload);
    return res;
  },
  async delete({ commit, state, dispatch }, { terminalId }) {
    const res = await this.$axios.$delete(`${api.resources}/${terminalId}`);
    return res;
  },
  async update({ commit, state }, payload = {}) {
    const { terminalId } = payload;
    const res = await this.$axios.$post(`${api.resources}/${terminalId}`, payload);
    return res;
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, payload) {
    state.items = payload.data;
    state.total = payload.state;
  },
  [types.USERLOADED](state, payload) {
    state.useritems = payload.data;
    state.usertotal = payload.state;
  },
};
