import * as types from '../.types.js';
import config from '@frame/config';
const { pageSize = 10 } = config;

const api = {
  items: '/xms/user/certs',
  orgCerts: '/xms/bff/org/certs',
};
export const state = () => ({
  items: [], //分页数据
  total: 0, // 总数
});
// actions
export const actions = {
  async delete({ commit, state }, { certId }) {
    const res = await this.$axios.$delete(`${api.items}/${certId}`);
    return res;
  },
  async query({ commit }, { filter = {}, paging = {} } = {}) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const params = { ...filter, skip, limit: size };
    const res = await this.$axios.$get(`${api.items}`, { params });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
  async orgCerts({ commit }, { filter = {}, paging = {} }) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const params = { ...filter, skip, limit: size };
    const res = await this.$axios.$get(`${api.orgCerts}`, { params });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
};
// mutations
export const mutations = {
  [types.LOADED](state, { data, total }) {
    state.items = data;
    state.total = total;
  },
  [types.DELETED](state, payload) {
    const idx = state.items.findIndex(p => p.certId === payload.certId);
    state.items.splice(idx, 1);
    state.total = state.total - 1;
  },
};
