import assert from 'assert';
import * as types from '../.types.js';
import config from '@frame/config';

const { pageSize = 10 } = config;
const baseUrlQuery = '/xms/bff/user/creds';
const baseUrl = '/xms/user/creds';
// initial state
export const state = () => ({
  items: [], //所有数据
  list: [], //指定用户凭证数据
  current: null,
  total: 0, // 数据项总数
});

// actions
export const actions = {
  async load({ commit }, payload = {}) {
    const res = await this.$axios.$get(`${baseUrl}`, { params: { ...payload } });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
  async query({ commit }, { filter = {}, type, paging = {} }) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const param = { type, skip, limit: size, ...filter };
    const res = await this.$axios.$get(`${baseUrlQuery}`, param);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
  async list({ commit }, { userId } = {}) {
    if (!userId) {
      commit(types.LISTED, { data: [] });
      return [];
    }
    const res = await this.$axios.$get(`${baseUrl}`, { userId });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LISTED, res);
    }
    return res;
  },
  async delete({ commit, state }, { credId }) {
    const res = await this.$axios.$delete(`${baseUrl}/${credId}`);
    commit(types.DELETED, credId);
    return res;
  },
  async create({ commit, state }, payload) {
    const { userId } = payload;
    const res = await this.$axios.$post(`${baseUrl}`, payload, { params: { userId } });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.CREATED, res);
    }
    return res;
  },
  async update({ commit, state }, payload) {
    const { name, data, expired, remark, status, credId } = payload;
    const res = await this.$axios.$post(`${baseUrl}/${credId}`, { name, data, expired, status, remark });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.UPDATED, res);
    }
    return res;
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, payload = {}) {
    ({ data: state.items, total: state.total } = payload);
  },
  [types.LISTED](state, { data }) {
    state.list = data;
  },
  [types.CREATED](state, payload) {
    state.items.push(payload);
    state.list.push(payload);
    state.current = payload;
  },
  [types.DELETED](state, credId) {
    let idx = state.items.findIndex(p => p.credId === credId);
    state.items.splice(idx, 1);
    idx = state.list.findIndex(p => p.credId === credId);
    state.list.splice(idx, 1);
    state.total = state.total - 1;
  },
  [types.UPDATED](state, payload) {
    let idx = state.items.findIndex(p => p.credId === payload.credId);
    state.items.splice(idx, 1, payload);
    idx = state.list.findIndex(p => p.credId === payload.credId);
    state.list.splice(idx, 1, payload);
  },
  [types.SELECTED](state, payload) {
    state.current = payload;
  },
};
