import assert from 'assert';
import * as types from '../.types.js';
import config from '@frame/config';

const { pageSize = 10 } = config;
const baseUrl = '/xms/device/infos';
// initial state
export const state = () => ({
  items: [], //所有数据
  list: [], //指定用户数据
  total: 0, // 数据项总数
});

// actions
export const actions = {
  async query({ commit }, { type, filter, paging = {} }) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const param = { type, skip, limit: size, ...filter };
    const res = await this.$axios.$get(`${baseUrl}`, param);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
  async list({ commit }, { userId } = {}) {
    if (!userId) {
      commit(types.LISTED, { data: [] });
      return [];
    }
    const res = await this.$axios.$get(`${baseUrl}`, { userId });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LISTED, res);
    }
    return res;
  },
  async delete({ commit, state }, { id }) {
    const res = await this.$axios.$delete(`${baseUrl}/${id}`);
    commit(types.DELETED, id);
    return res;
  },
  async create({ commit, state }, payload) {
    const { type } = payload;
    const res = await this.$axios.$post(`${baseUrl}?dataType=${type}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.CREATED, res);
    }
    return res;
  },
  async update({ commit, state }, payload) {
    const { id } = payload;
    const res = await this.$axios.$post(`${baseUrl}/${id}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.UPDATED, res);
    }
    return res;
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, payload = {}) {
    ({ data: state.items, total: state.total } = payload);
  },
  [types.LISTED](state, { data }) {
    state.list = data;
  },
  [types.CREATED](state, payload) {
    state.items.push(payload);
    state.list.push(payload);
    state.current = payload;
    state.total = state.total + 1;
  },
  [types.DELETED](state, payload) {
    let idx = state.items.findIndex(p => p.id === payload);
    state.items.splice(idx, 1);
    idx = state.list.findIndex(p => p.id === payload);
    state.list.splice(idx, 1);
    state.total = state.total - 1;
  },
  [types.UPDATED](state, payload) {
    let idx = state.items.findIndex(p => p.id === payload.id);
    state.items.splice(idx, 1, payload);
    idx = state.list.findIndex(p => p.id === payload.id);
    state.list.splice(idx, 1, payload);
  },
  [types.SELECTED](state, payload) {
    state.current = payload;
  },
};
