import * as types from '../.types.js';
import _ from 'lodash';
import config from '@frame/config';
const { pageSize = 10 } = config;
// transfer
const baseUrl = '/xms/user/orgs';
const api = {
  // 应用帐号绑定关系 source appId  target acctId
  appBind: '/xms/bind/org-app/items',
  // 帐号角色绑定关系 source acctId  target roleId
  roleBind: '/xms/bind/org-role/items',
  apps: '/xms/bff/org/apps',
  roles: '/xms/bff/org/roles',
};
// initial state
// shape: [{ id, quantity }]
export const state = () => ({
  items: [], //所有数据
  current: null,
  total: 0,
  lists: [],
  apps: [],
  roles: [],
  // 机构绑定的所有角色
  rolesAll: [],
  rolestotal: 0,
});

// actions
export const actions = {
  async load({ commit }, { filter } = {}) {
    const res = await this.$axios.$get(`${baseUrl}`, { ...filter, 'sort.property': 'orderNum', limit: 2000 });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
  async loadall({ commit }, { filter } = {}) {
    const res = await this.$axios.$get(`${baseUrl}`, { ...filter, 'sort.property': 'orderNum', limit: 2000 });
    if (res.errcode === undefined || res.errcode === 0) {
      commit('LOADEDS', res);
    }
    return res;
  },
  async create({ commit, state }, payload) {
    const { parentId = '', code, name, level, remark } = payload;
    const res = await this.$axios.$post(`${baseUrl}`, { parentId, code, name, level, remark }, { params: { parentId } });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.CREATED, res);
    }
    return res;
  },
  async delete({ commit, state }, { id, orgId = id }) {
    const res = await this.$axios.$delete(`${baseUrl}/${orgId}`);
    commit(types.DELETED, res);
    return res;
  },
  async update({ commit, state }, payload = {}) {
    const { orgId, parentId, name, code, level, remark } = payload;
    const res = await this.$axios.$post(`${baseUrl}/${orgId}`, { parentId, code, name, level, remark });
    if (res.errcode === undefined || res.errcode === 0) commit(types.UPDATED, res);
    return res;
  },
  // 机构迁移
  async transfer({ commit, state }, payload) {
    const { orgId, parentId } = payload;
    const res = await this.$axios.$post(`${baseUrl}/${orgId}/transfer`, {}, { parentId });
    return res;
  },
  // 添加部门应用绑定
  async bindApp({ commit, state, dispatch }, { userId, appId, orgId, mode = [], bindId } = {}) {
    let res;
    const param = mode.join(',');
    if (!bindId) {
      // 添加帐号和应用绑定关系
      res = await this.$axios.$post(`${api.appBind}`, { source: orgId, target: appId, userId, appId, param });
    } else {
      // 修改帐号和应用绑定参数
      res = await this.$axios.$post(`${api.appBind}/${bindId}`, { param });
    }
    if (res.errcode === undefined || res.errcode === 0) {
      // 重新加载帐号app列表
      dispatch('fetchOrgApps', { orgId });
    }
    return res;
  },
  // 删除部门应用绑定
  async deleteOrgApp({ commit, state, dispatch }, { orgId, appId }) {
    let res = await this.$axios.$delete(`${api.appBind}`, { source: orgId, target: appId });
    if (res.errcode && res.errcode !== 0) {
      console.warn('删除帐号-应用关系失败');
      return res;
    }
    if (res.errcode === undefined || res.errcode === 0) {
      // 重新加载帐号app列表
      dispatch('fetchOrgApps', { orgId });
    }
    // 删除帐号中该应用角色
    res = await this.$axios.$delete(`${api.roleBind}`, { appId, source: orgId });
    return res;
  },
  // 添加部门角色绑定关系
  async bindRoles({ commit, state, dispatch }, { appId, orgId, roles } = {}) {
    const res = await this.$axios.$post(`${api.roleBind}/batch`, { source: orgId, targets: roles, appId });
    return res;
  },
  // 删除角色
  async deleteRoles({ commit, state }, { ids = [] }) {
    return Promise.all(ids.map(e => this.$axios.$delete(`${api.roleBind}/${e}`)));
  },
  // 查询部门绑定的应用
  async fetchOrgApps({ commit, dispatch }, { orgId }) {
    if (!orgId) {
      commit('apps', []); // clear
      return;
    }
    const res = await this.$axios.$get(`${api.apps}`, { orgId });
    if (res.errcode === undefined || res.errcode === 0) {
      commit('apps', res.data);
    }
    return res;
  },
  // 查询部门应用  角色
  async fetchOrgRoles({ commit, dispatch }, { orgId, appId }) {
    if (!orgId || !appId) {
      commit('roles', []); // clear
      return;
    }
    const res = await this.$axios.$get(`${api.roleBind}`, { source: orgId, appId });
    if (res.errcode === undefined || res.errcode === 0) {
      commit('roles', res.data);
    }
    return res;
  },
  // 查询所有角色
  async OrgRoles({ commit, dispatch }, { orgId, appId }) {
    if (!orgId) {
      commit('rolesAll', []); // clear
      return;
    }
    const res = await this.$axios.$get(`${api.roleBind}`, { source: orgId, appId });
    if (res.errcode === undefined || res.errcode === 0) {
      commit('rolesAll', res);
    }
    return res;
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, { data, total }) {
    state.items = data;
    state.total = total;
  },
  [types.SELECTED](state, payload) {
    state.current = payload;
  },
  [types.CREATED](state, payload) {
    state.items.push(payload);
    state.total = state.total + 1;
  },
  [types.DELETED](state, payload) {
    let idx = state.items.findIndex(p => p.orgId === payload.orgId);
    state.items.splice(idx, 1);
    state.total = state.total - 1;
  },
  [types.UPDATED](state, payload) {
    let idx = state.items.findIndex(p => p.orgId === payload.orgId);
    state.items.splice(idx, 1, payload);
  },
  apps(state, datas) {
    state.apps = datas;
  },
  roles(state, payload) {
    state.roles = payload;
  },
  rolesAll(state, payload) {
    state.rolesAll = payload.data;
    state.rolestotal = payload.total;
  },
  LOADEDS(state, { data, total }) {
    state.items = data;
    state.total = total;
    state.lists = data;
  },
};
