import assert from 'assert';
import * as types from '../.types.js';
import _ from 'lodash';
import config from '@frame/config';
const { pageSize = 10 } = config;

const api = {
  regs: '/xms/user/regs',
  img: '/xms/file/reg/items',
};
// initial state
// shape: [{ id, quantity }]
export const state = () => ({
  items: [],
  list: [],
  totalItems: null,
  totalList: null,
  item: null,
  creds: [],
});

// actions
export const actions = {
  async imgQuery({ commit, state, dispatch }, { ownerId }) {
    const res = await this.$axios.$get(`${api.img}`, { ownerId });
    return res;
  },
  async query({ commit }, { filters = {}, paging = {} } = {}) {
    let skip = (paging.page - 1) * paging.size || 0;
    let limit = paging.size || 10;
    const res = await this.$axios.$get(api.regs, { skip, limit, ...filters });
    commit('alreadyQuery', res);
    return res;
  },
  // 审核
  async review({ commit, state, dispatch }, payload) {
    const { userId, status } = payload;
    const res = await this.$axios.$post(`${api.regs}/${userId}`, payload, { status });
    return res;
  },
  // 删除
  async delete({ commit, state }, { id }) {
    const res = await this.$axios.$delete(`${api.regs}/${id}`);
    return res;
  },
  // 查询凭证
  async credQuery({ commit, state, dispatch }, { userId }) {
    const res = await this.$axios.$get(`${api.regs}/creds`, { userId });
    if (res.errcode === undefined || res.errcode === 0) {
      commit('cred', res.data);
    }
    return res;
  },
  // 删除凭证
  async credDelete({ commit, state, dispatch }, { userId, credId }) {
    const res = await this.$axios.$delete(`${api.regs}/creds/${credId}`, { userId });
    if (res.errcode === undefined || res.errcode === 0) {
      commit('credDelete', { credId });
    }
    return res;
  },
};

// mutations
export const mutations = {
  notQuery(state, payload = {}) {
    state.items = payload.data;
    state.totalItems = payload.total;
  },
  alreadyQuery(state, payload = {}) {
    state.list = payload.data;
    state.totalList = payload.total;
  },
  [types.CREATED](state, payload) {
    const idx = state.items.findIndex(p => p.userId === payload.id);
    state.list.push(state.items[idx]);
    state.items.splice(idx, 1);
  },
  [types.DELETED](state, payload) {
    const idx = state.items.findIndex(p => p.userId === payload.id);
    state.items.splice(idx, 1);
  },
  noVerify(state, payload) {
    const idx = state.list.findIndex(p => p.userId === payload.id);
    state.list.splice(idx, 1);
  },
  fetch(state, payload) {
    state.item = payload;
  },
  cred(state, payload) {
    state.creds = payload;
  },
  credDelete(state, payload) {
    const idx = state.creds.findIndex(p => p.credId === payload.credId);
    state.creds.splice(idx, 1);
  },
};
