import * as types from '../.types.js';
import config from '@frame/config';
const { pageSize = 10 } = config;
const api = {
  items: '/xms/user/rules',
  // 帐号角色绑定关系 source acctId  target roleId
  roleBind: '/xms/bind/rule-role/items',
  apps: '/xms/bff/rules/apps',
  roles: '/xms/bff/rules/roles',
  ruleRser: '/xms/bff/rule/users',
};

// initial state
export const state = () => ({
  items: [], // 群组列表
  total: 0, // 总数
  current: null,
  apps: [],
  roles: [],
  roleAll: null,
  roletotal: 0,
  userList: [],
  userTotal: 0,
});

// actions
export const actions = {
  // 创建群组
  async create({ commit, state }, payload) {
    const res = await this.$axios.$post(`${api.items}`, payload);
    return res;
  },
  async ruleRser({ commit, state }, { ruleId, filter = {}, paging = {} }) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const res = await this.$axios.$get(`${api.ruleRser}`, { skip, limit: size, ...filter });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.CREATED, res);
    }
    return res;
  },
  // 更新群组
  async update({ commit, state }, payload = {}) {
    const { ruleId } = payload;
    const res = await this.$axios.$post(`${api.items}/${ruleId}`, payload);
    // if (res.errcode === undefined || res.errcode === 0) commit(types.UPDATED, res);
    return res;
  },
  // 删除群组
  async delete({ commit, state }, payload = {}) {
    const { ruleId } = payload;
    const res = await this.$axios.$delete(`${api.items}/${ruleId}`);
    // if (res.errcode === undefined || res.errcode === 0) commit(types.DELETED, { ruleId });
    return res;
  },
  // 查询群组列表
  async load({ state, commit }, payload) {
    const res = await this.$axios.$get(`${api.items}`, { limit: 500 });
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res.data);
    }
    return res;
  },
  // 添加规则角色绑定关系
  async bindRoles({ commit, state, dispatch }, { appId, ruleId, roles } = {}) {
    const res = await this.$axios.$post(`${api.roleBind}/batch`, { source: ruleId, targets: roles, appId });
    return res;
  },
  // 删除角色
  async deleteRoles({ commit, state }, { ids = [] }) {
    return Promise.all(ids.map(e => this.$axios.$delete(`${api.roleBind}/${e}`)));
  },
  // 查询群组应用  角色
  async fetchRuleRoles({ commit, dispatch }, { ruleId, appId }) {
    if (!ruleId || !appId) {
      commit('roles', []); // clear
      return;
    }
    const res = await this.$axios.$get(`${api.roleBind}`, { source: ruleId, appId });
    if (res.errcode === undefined || res.errcode === 0) {
      commit('roles', res.data);
    }
    return res;
  },
  // 查询规则所有  角色
  async rulesRoles({ commit, dispatch }, { ruleId }) {
    if (!ruleId) {
      commit('rulesRoles', []); // clear
      return;
    }
    const res = await this.$axios.$get(`${api.roleBind}`, { source: ruleId });
    if (res.errcode === undefined || res.errcode === 0) {
      commit('rulesRoles', res);
    }
    return res;
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, payload) {
    state.items = payload;
  },
  [types.CREATED](state, payload) {
    state.userList = payload.data;
    state.userTotal = payload.total;
  },
  [types.DELETED](state, payload) {
    let idx = state.items.findIndex(p => p.ruleId === payload.ruleId);
    state.items.splice(idx, 1);
  },
  [types.UPDATED](state, payload) {
    let idx = state.items.findIndex(p => p.ruleId === payload.ruleId);
    state.items.splice(idx, 1, payload);
  },
  rulesRoles(state, payload) {
    state.roleAll = payload.data;
    state.roletotal = payload.total;
  },
  roles(state, payload) {
    state.roles = payload;
  },
};
