import assert from 'assert';
import * as types from '../.types.js';
import config from '@frame/config';

const { pageSize = 10 } = config;
const api = {
  infos: '/xms/app/policy/infos',
  items: '/xms/app/policy/items',
  batchUpload: '/xms/app/policy/items/batch',
};
// initial state
export const state = () => ({
  items: [], //所有数据
  total: 0, // 数据项总数
  list: [],
  listTotal: 0,
});

// actions
export const actions = {
  async query({ commit }) {
    const res = await this.$axios.$get(`${api.infos}`);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.LOADED, res);
    }
    return res;
  },
  async delete({ commit, state }, { id }) {
    const res = await this.$axios.$delete(`${api.infos}/${id}`);
    return res;
  },
  async create({ commit, state }, payload = {}) {
    const res = await this.$axios.$post(`${api.infos}`, payload);
    // if (res.errcode === undefined || res.errcode === 0) {
    //   commit(types.CREATED, res);
    // }
    return res;
  },
  async batchUpload({ commit, state }, payload) {
    const res = await this.$axios.$post(`${api.batchUpload}`, payload);
    return res;
  },
  async update({ commit, state }, payload) {
    const { id } = payload;
    const res = await this.$axios.$post(`${api.infos}/${id}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      commit(types.UPDATED, res);
    }
    return res;
  },
  async itemsQuery({ commit }, { filter, paging = {} }) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const param = { skip, limit: size, ...filter };
    const res = await this.$axios.$get(`${api.items}`, param);
    if (res.errcode === undefined || res.errcode === 0) {
      commit('query', res);
    }
    return res;
  },
  async itemsDelete({ commit, state }, { id }) {
    const res = await this.$axios.$delete(`${api.items}/${id}`);
    if (res.errcode === undefined || res.errcode === 0) commit('itemsdelete', { id });
    return res;
  },
  async itemsCreate({ commit, state }, payload) {
    const { userId } = payload;
    const res = await this.$axios.$post(`${api.items}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      commit('itemsCreate', res);
    }
    return res;
  },
  async itemsUpdate({ commit, state }, payload) {
    const { id } = payload;
    const res = await this.$axios.$post(`${api.items}/${id}`, payload);
    if (res.errcode === undefined || res.errcode === 0) {
      commit('itemsUpdate', res);
    }
    return res;
  },
};

// mutations
export const mutations = {
  [types.LOADED](state, payload = {}) {
    ({ data: state.items, total: state.total } = payload);
  },
  [types.CREATED](state, payload) {
    state.items.push(payload);
  },
  [types.DELETED](state, payload) {
    let idx = state.items.findIndex(p => p.policyId === payload.id);
    state.items.splice(idx, 1);
  },
  [types.UPDATED](state, payload) {
    let idx = state.items.findIndex(p => p.id === payload.id);
    state.items.splice(idx, 1, payload);
    idx = state.list.findIndex(p => p.id === payload.id);
    state.list.splice(idx, 1, payload);
  },
  [types.SELECTED](state, payload) {
    state.current = payload;
  },
  query(state, payload = {}) {
    ({ data: state.list, total: state.listTotal } = payload);
  },
  itemsdelete(state, payload) {
    let idx = state.list.findIndex(p => p.id === payload.id);
    state.list.splice(idx, 1);
    state.listTotal = state.listTotal - 1;
  },
  itemsCreate(state, payload) {
    state.list.push(payload);
  },
  itemsUpdate(state, payload) {
    const idx = state.list.findIndex(p => p.id === payload.id);
    state.list.splice(idx, 1, payload);
  },
  load(state) {
    state.list = [];
  },
  forms(state, payload) {
    state.list[payload.i].value = payload.e;
  },
};
