import config from '@frame/config';
const { pageSize = 10 } = config;
const api = {
  task: '/xms/task',
  csv2xls: 'xms/task/util/csv2xls',
};

// 参数帐号id  appid
// initial state
export const state = () => ({
  list: null,
  total: 0,
});

// actions
export const actions = {
  // 上传
  async uploads({ commit, state }, { type, file, option, subType }) {
    let param = new FormData();
    let config = { headers: { 'Content-Type': 'multipart/form-data' } };
    param.append('file', file);
    let res;
    if (subType) {
      res = await this.$axios.$post(`${api.task}/${type}/import?subType=${subType}`, param, { option }, config);
    } else {
      res = await this.$axios.$post(`${api.task}/${type}/import`, param, { option }, config);
    }
    return res;
  },
  // 导出
  async export({ commit, state }, { type, fileType, payload }) {
    const res = await this.$axios.$post(`${api.task}/${type}/export`, { ...payload }, { fileType });
    return res;
  },
  // 进度
  async progressInfo({ commit, state }, { id }) {
    const res = await this.$axios.$get(`${api.task}/${id}`);
    return res;
  },
  // 下载导出文件
  async download({ commit, state }, { id, fileName }) {
    const res = await this.$axios.$get(`${api.task}/${id}/download`, { fileName });
    return res;
  },
  // 任务列表
  async taskList({ commit, state }, { filter = {}, paging = {} } = {}) {
    const { page = 1, size = pageSize } = paging;
    const skip = Math.max(0, (page - 1) * size);
    const res = await this.$axios.$get(`${api.task}/items`, { ...filter, skip, limit: size });
    if (res.errcode === undefined || res.errcode === 0) {
      commit('list', res);
    }
    return res;
  },
  // csv转换
  async csv2xls({ commit, state }, { fileName, payload }) {
    const options = { unwrap: false, responseType: 'blob', headers: { 'Content-Type': 'text/csv' } };
    const res = await this.$axios.$post(`${api.csv2xls}`, payload, { fileName }, options);
    return res;
  },
};

// mutations
export const mutations = {
  list(state, payload) {
    state.list = payload.data;
    state.total = payload.total;
  },
};
